from google.protobuf import wrappers_pb2 as _wrappers_pb2
from vemmio_client import devices_pb2 as _devices_pb2
from vemmio_client import metadata_pb2 as _metadata_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
NODE_STATUS_ALIVE: ZWaveNodeStatus
NODE_STATUS_DOWN: ZWaveNodeStatus
NODE_STATUS_SLEEP: ZWaveNodeStatus
NODE_STATUS_UNSPECIFIED: ZWaveNodeStatus
ZWAVE_HEALTH_CRITICAL: ZWaveHealthCategory
ZWAVE_HEALTH_GREEN: ZWaveHealthCategory
ZWAVE_HEALTH_RED: ZWaveHealthCategory
ZWAVE_HEALTH_UNSPECIFIED: ZWaveHealthCategory
ZWAVE_HEALTH_YELLOW: ZWaveHealthCategory

class ZWaveAbortRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveAbortResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveAddEntryRequest(_message.Message):
    __slots__ = ["dsk", "info"]
    DSK_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    dsk: str
    info: _containers.RepeatedCompositeFieldContainer[ZWaveProvisioningInfo]
    def __init__(self, dsk: _Optional[str] = ..., info: _Optional[_Iterable[_Union[ZWaveProvisioningInfo, _Mapping]]] = ...) -> None: ...

class ZWaveAddEntryResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveEndpoint(_message.Message):
    __slots__ = ["ep_id", "generic_class", "interfaces", "specific_class"]
    EP_ID_FIELD_NUMBER: _ClassVar[int]
    GENERIC_CLASS_FIELD_NUMBER: _ClassVar[int]
    INTERFACES_FIELD_NUMBER: _ClassVar[int]
    SPECIFIC_CLASS_FIELD_NUMBER: _ClassVar[int]
    ep_id: int
    generic_class: int
    interfaces: _containers.RepeatedCompositeFieldContainer[ZWaveInterface]
    specific_class: int
    def __init__(self, ep_id: _Optional[int] = ..., generic_class: _Optional[int] = ..., specific_class: _Optional[int] = ..., interfaces: _Optional[_Iterable[_Union[ZWaveInterface, _Mapping]]] = ...) -> None: ...

class ZWaveExcludeRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveExcludeStatus(_message.Message):
    __slots__ = ["not_found", "progress", "ready", "removed"]
    class DeviceNotFound(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    class DeviceRemoved(_message.Message):
        __slots__ = ["metadata"]
        METADATA_FIELD_NUMBER: _ClassVar[int]
        metadata: _metadata_pb2.ZWaveMetadata
        def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ZWaveMetadata, _Mapping]] = ...) -> None: ...
    class ExcludeProgress(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    class ExcludeReady(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    NOT_FOUND_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_FIELD_NUMBER: _ClassVar[int]
    READY_FIELD_NUMBER: _ClassVar[int]
    REMOVED_FIELD_NUMBER: _ClassVar[int]
    not_found: ZWaveExcludeStatus.DeviceNotFound
    progress: ZWaveExcludeStatus.ExcludeProgress
    ready: ZWaveExcludeStatus.ExcludeReady
    removed: ZWaveExcludeStatus.DeviceRemoved
    def __init__(self, removed: _Optional[_Union[ZWaveExcludeStatus.DeviceRemoved, _Mapping]] = ..., ready: _Optional[_Union[ZWaveExcludeStatus.ExcludeReady, _Mapping]] = ..., progress: _Optional[_Union[ZWaveExcludeStatus.ExcludeProgress, _Mapping]] = ..., not_found: _Optional[_Union[ZWaveExcludeStatus.DeviceNotFound, _Mapping]] = ...) -> None: ...

class ZWaveHealRequest(_message.Message):
    __slots__ = ["init_return_routes", "node_id"]
    INIT_RETURN_ROUTES_FIELD_NUMBER: _ClassVar[int]
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    init_return_routes: bool
    node_id: _wrappers_pb2.Int32Value
    def __init__(self, node_id: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ..., init_return_routes: bool = ...) -> None: ...

class ZWaveHealResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveHealthCheckCompleted(_message.Message):
    __slots__ = ["nodes"]
    NODES_FIELD_NUMBER: _ClassVar[int]
    nodes: _containers.RepeatedCompositeFieldContainer[ZWaveHealthStatusNode]
    def __init__(self, nodes: _Optional[_Iterable[_Union[ZWaveHealthStatusNode, _Mapping]]] = ...) -> None: ...

class ZWaveHealthCheckProgress(_message.Message):
    __slots__ = ["count", "total"]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    count: int
    total: int
    def __init__(self, count: _Optional[int] = ..., total: _Optional[int] = ...) -> None: ...

class ZWaveHealthCheckRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveHealthCheckStarted(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveHealthCheckStatus(_message.Message):
    __slots__ = ["completed", "progress", "started"]
    COMPLETED_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_FIELD_NUMBER: _ClassVar[int]
    STARTED_FIELD_NUMBER: _ClassVar[int]
    completed: ZWaveHealthCheckCompleted
    progress: ZWaveHealthCheckProgress
    started: ZWaveHealthCheckStarted
    def __init__(self, started: _Optional[_Union[ZWaveHealthCheckStarted, _Mapping]] = ..., progress: _Optional[_Union[ZWaveHealthCheckProgress, _Mapping]] = ..., completed: _Optional[_Union[ZWaveHealthCheckCompleted, _Mapping]] = ...) -> None: ...

class ZWaveHealthStatusNode(_message.Message):
    __slots__ = ["category", "node_id", "value"]
    CATEGORY_FIELD_NUMBER: _ClassVar[int]
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    category: ZWaveHealthCategory
    node_id: int
    value: int
    def __init__(self, node_id: _Optional[int] = ..., category: _Optional[_Union[ZWaveHealthCategory, str]] = ..., value: _Optional[int] = ...) -> None: ...

class ZWaveIncludeRequest(_message.Message):
    __slots__ = ["secure"]
    SECURE_FIELD_NUMBER: _ClassVar[int]
    secure: bool
    def __init__(self, secure: bool = ...) -> None: ...

class ZWaveIncludeStatus(_message.Message):
    __slots__ = ["added", "found", "progress", "ready"]
    class DeviceAdded(_message.Message):
        __slots__ = ["devices"]
        DEVICES_FIELD_NUMBER: _ClassVar[int]
        devices: _containers.RepeatedCompositeFieldContainer[_devices_pb2.Device]
        def __init__(self, devices: _Optional[_Iterable[_Union[_devices_pb2.Device, _Mapping]]] = ...) -> None: ...
    class DeviceFound(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    class IncludeProgress(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    class IncludeReady(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    ADDED_FIELD_NUMBER: _ClassVar[int]
    FOUND_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_FIELD_NUMBER: _ClassVar[int]
    READY_FIELD_NUMBER: _ClassVar[int]
    added: ZWaveIncludeStatus.DeviceAdded
    found: ZWaveIncludeStatus.DeviceFound
    progress: ZWaveIncludeStatus.IncludeProgress
    ready: ZWaveIncludeStatus.IncludeReady
    def __init__(self, found: _Optional[_Union[ZWaveIncludeStatus.DeviceFound, _Mapping]] = ..., added: _Optional[_Union[ZWaveIncludeStatus.DeviceAdded, _Mapping]] = ..., ready: _Optional[_Union[ZWaveIncludeStatus.IncludeReady, _Mapping]] = ..., progress: _Optional[_Union[ZWaveIncludeStatus.IncludeProgress, _Mapping]] = ...) -> None: ...

class ZWaveInterface(_message.Message):
    __slots__ = ["command_class", "help", "items", "label", "real_version", "version"]
    COMMAND_CLASS_FIELD_NUMBER: _ClassVar[int]
    HELP_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    REAL_VERSION_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    command_class: int
    help: str
    items: _containers.RepeatedCompositeFieldContainer[ZWaveValueItem]
    label: str
    real_version: int
    version: int
    def __init__(self, command_class: _Optional[int] = ..., version: _Optional[int] = ..., real_version: _Optional[int] = ..., label: _Optional[str] = ..., help: _Optional[str] = ..., items: _Optional[_Iterable[_Union[ZWaveValueItem, _Mapping]]] = ...) -> None: ...

class ZWaveListEntriesRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveListEntriesResponse(_message.Message):
    __slots__ = ["entries"]
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    entries: _containers.RepeatedCompositeFieldContainer[ZWaveProvisioningEntry]
    def __init__(self, entries: _Optional[_Iterable[_Union[ZWaveProvisioningEntry, _Mapping]]] = ...) -> None: ...

class ZWaveNetworkTopologyUpdateStarted(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveNode(_message.Message):
    __slots__ = ["endpoints", "manufacturer_name", "node_id", "product_id", "product_name", "product_type", "status", "user_name", "vendor_id"]
    ENDPOINTS_FIELD_NUMBER: _ClassVar[int]
    MANUFACTURER_NAME_FIELD_NUMBER: _ClassVar[int]
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_NAME_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_TYPE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    USER_NAME_FIELD_NUMBER: _ClassVar[int]
    VENDOR_ID_FIELD_NUMBER: _ClassVar[int]
    endpoints: _containers.RepeatedCompositeFieldContainer[ZWaveEndpoint]
    manufacturer_name: str
    node_id: int
    product_id: int
    product_name: str
    product_type: int
    status: ZWaveNodeStatus
    user_name: str
    vendor_id: int
    def __init__(self, node_id: _Optional[int] = ..., vendor_id: _Optional[int] = ..., product_type: _Optional[int] = ..., product_id: _Optional[int] = ..., endpoints: _Optional[_Iterable[_Union[ZWaveEndpoint, _Mapping]]] = ..., manufacturer_name: _Optional[str] = ..., product_name: _Optional[str] = ..., user_name: _Optional[str] = ..., status: _Optional[_Union[ZWaveNodeStatus, str]] = ...) -> None: ...

class ZWaveNodeInformationUpdateStarted(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveNodeNeighborUpdateStarted(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveNodeRequest(_message.Message):
    __slots__ = ["node_id"]
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    node_id: int
    def __init__(self, node_id: _Optional[int] = ...) -> None: ...

class ZWaveNodeResponse(_message.Message):
    __slots__ = ["node"]
    NODE_FIELD_NUMBER: _ClassVar[int]
    node: ZWaveNode
    def __init__(self, node: _Optional[_Union[ZWaveNode, _Mapping]] = ...) -> None: ...

class ZWaveNodesRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveNodesResponse(_message.Message):
    __slots__ = ["nodes"]
    NODES_FIELD_NUMBER: _ClassVar[int]
    nodes: _containers.RepeatedCompositeFieldContainer[ZWaveNode]
    def __init__(self, nodes: _Optional[_Iterable[_Union[ZWaveNode, _Mapping]]] = ...) -> None: ...

class ZWaveNotificationItemsRequest(_message.Message):
    __slots__ = ["ep_id", "index", "node_id"]
    EP_ID_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    ep_id: int
    index: int
    node_id: int
    def __init__(self, node_id: _Optional[int] = ..., ep_id: _Optional[int] = ..., index: _Optional[int] = ...) -> None: ...

class ZWaveNotificationItemsResponse(_message.Message):
    __slots__ = ["items"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, items: _Optional[_Iterable[int]] = ...) -> None: ...

class ZWaveProvisioningEntry(_message.Message):
    __slots__ = ["dsk", "info"]
    DSK_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    dsk: str
    info: _containers.RepeatedCompositeFieldContainer[ZWaveProvisioningInfo]
    def __init__(self, dsk: _Optional[str] = ..., info: _Optional[_Iterable[_Union[ZWaveProvisioningInfo, _Mapping]]] = ...) -> None: ...

class ZWaveProvisioningInfo(_message.Message):
    __slots__ = ["bootstrapping_mode", "granted_keys", "inclusion_interval", "inclusion_status", "location", "name", "network_status", "product_id", "product_type", "uuid"]
    BOOTSTRAPPING_MODE_FIELD_NUMBER: _ClassVar[int]
    GRANTED_KEYS_FIELD_NUMBER: _ClassVar[int]
    INCLUSION_INTERVAL_FIELD_NUMBER: _ClassVar[int]
    INCLUSION_STATUS_FIELD_NUMBER: _ClassVar[int]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NETWORK_STATUS_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_TYPE_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    bootstrapping_mode: int
    granted_keys: int
    inclusion_interval: int
    inclusion_status: int
    location: str
    name: str
    network_status: ZWaveProvisioningInfoNetworkStatus
    product_id: ZWaveProvisioningInfoProductID
    product_type: ZWaveProvisioningInfoProductType
    uuid: str
    def __init__(self, product_type: _Optional[_Union[ZWaveProvisioningInfoProductType, _Mapping]] = ..., product_id: _Optional[_Union[ZWaveProvisioningInfoProductID, _Mapping]] = ..., inclusion_interval: _Optional[int] = ..., uuid: _Optional[str] = ..., name: _Optional[str] = ..., location: _Optional[str] = ..., inclusion_status: _Optional[int] = ..., granted_keys: _Optional[int] = ..., bootstrapping_mode: _Optional[int] = ..., network_status: _Optional[_Union[ZWaveProvisioningInfoNetworkStatus, _Mapping]] = ...) -> None: ...

class ZWaveProvisioningInfoNetworkStatus(_message.Message):
    __slots__ = ["node_id", "status"]
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    node_id: int
    status: int
    def __init__(self, node_id: _Optional[int] = ..., status: _Optional[int] = ...) -> None: ...

class ZWaveProvisioningInfoProductID(_message.Message):
    __slots__ = ["application_sub_version", "application_version", "manufacturer_id", "product_id", "product_type"]
    APPLICATION_SUB_VERSION_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_VERSION_FIELD_NUMBER: _ClassVar[int]
    MANUFACTURER_ID_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_TYPE_FIELD_NUMBER: _ClassVar[int]
    application_sub_version: int
    application_version: int
    manufacturer_id: int
    product_id: int
    product_type: int
    def __init__(self, manufacturer_id: _Optional[int] = ..., product_type: _Optional[int] = ..., product_id: _Optional[int] = ..., application_version: _Optional[int] = ..., application_sub_version: _Optional[int] = ...) -> None: ...

class ZWaveProvisioningInfoProductType(_message.Message):
    __slots__ = ["generic_class", "icon_type", "specific_class"]
    GENERIC_CLASS_FIELD_NUMBER: _ClassVar[int]
    ICON_TYPE_FIELD_NUMBER: _ClassVar[int]
    SPECIFIC_CLASS_FIELD_NUMBER: _ClassVar[int]
    generic_class: int
    icon_type: int
    specific_class: int
    def __init__(self, generic_class: _Optional[int] = ..., specific_class: _Optional[int] = ..., icon_type: _Optional[int] = ...) -> None: ...

class ZWaveRemoveEntryRequest(_message.Message):
    __slots__ = ["dsk"]
    DSK_FIELD_NUMBER: _ClassVar[int]
    dsk: str
    def __init__(self, dsk: _Optional[str] = ...) -> None: ...

class ZWaveRemoveEntryResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveRemoveFailedRequest(_message.Message):
    __slots__ = ["node_id"]
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    node_id: int
    def __init__(self, node_id: _Optional[int] = ...) -> None: ...

class ZWaveRemoveFailedResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveReplaceFailedRequest(_message.Message):
    __slots__ = ["node_id"]
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    node_id: int
    def __init__(self, node_id: _Optional[int] = ...) -> None: ...

class ZWaveReplaceFailedResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveResetRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveResetResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveTestRequest(_message.Message):
    __slots__ = ["count", "node_id"]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    count: int
    node_id: _wrappers_pb2.Int32Value
    def __init__(self, node_id: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ..., count: _Optional[int] = ...) -> None: ...

class ZWaveTestResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveUpdateNodeRequest(_message.Message):
    __slots__ = ["node_id"]
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    node_id: int
    def __init__(self, node_id: _Optional[int] = ...) -> None: ...

class ZWaveUpdateNodeResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveUpdateRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZWaveUpdateStatus(_message.Message):
    __slots__ = ["neighbor", "node_info", "topology"]
    NEIGHBOR_FIELD_NUMBER: _ClassVar[int]
    NODE_INFO_FIELD_NUMBER: _ClassVar[int]
    TOPOLOGY_FIELD_NUMBER: _ClassVar[int]
    neighbor: ZWaveNodeNeighborUpdateStarted
    node_info: ZWaveNodeInformationUpdateStarted
    topology: ZWaveNetworkTopologyUpdateStarted
    def __init__(self, topology: _Optional[_Union[ZWaveNetworkTopologyUpdateStarted, _Mapping]] = ..., neighbor: _Optional[_Union[ZWaveNodeNeighborUpdateStarted, _Mapping]] = ..., node_info: _Optional[_Union[ZWaveNodeInformationUpdateStarted, _Mapping]] = ...) -> None: ...

class ZWaveValueItem(_message.Message):
    __slots__ = ["label", "value"]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    label: str
    value: int
    def __init__(self, value: _Optional[int] = ..., label: _Optional[str] = ...) -> None: ...

class ZWaveHealthCategory(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class ZWaveNodeStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from vemmio_client import metadata_pb2 as _metadata_pb2
from vemmio_client import units_pb2 as _units_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
THERMOSTAT_FAN_MODE_AUTO_HIGH: ThermostatFanMode
THERMOSTAT_FAN_MODE_AUTO_LOW: ThermostatFanMode
THERMOSTAT_FAN_MODE_HIGH: ThermostatFanMode
THERMOSTAT_FAN_MODE_LOW: ThermostatFanMode
THERMOSTAT_FAN_MODE_OFF: ThermostatFanMode
THERMOSTAT_MODE_AUTO: ThermostatMode
THERMOSTAT_MODE_COOL: ThermostatMode
THERMOSTAT_MODE_HEAT: ThermostatMode
THERMOSTAT_MODE_OFF: ThermostatMode
THERMOSTAT_SETPOINT_TYPE_AUTO: ThermostatSetpointType
THERMOSTAT_SETPOINT_TYPE_COOL: ThermostatSetpointType
THERMOSTAT_SETPOINT_TYPE_HEAT: ThermostatSetpointType

class ThermostatFanModeReport(_message.Message):
    __slots__ = ["fan_mode"]
    FAN_MODE_FIELD_NUMBER: _ClassVar[int]
    fan_mode: ThermostatFanMode
    def __init__(self, fan_mode: _Optional[_Union[ThermostatFanMode, str]] = ...) -> None: ...

class ThermostatFanModeSetRequest(_message.Message):
    __slots__ = ["fan_mode", "metadata"]
    FAN_MODE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    fan_mode: ThermostatFanMode
    metadata: _metadata_pb2.DeviceMetadata
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ..., fan_mode: _Optional[_Union[ThermostatFanMode, str]] = ...) -> None: ...

class ThermostatModeReport(_message.Message):
    __slots__ = ["mode"]
    MODE_FIELD_NUMBER: _ClassVar[int]
    mode: ThermostatMode
    def __init__(self, mode: _Optional[_Union[ThermostatMode, str]] = ...) -> None: ...

class ThermostatModeSetRequest(_message.Message):
    __slots__ = ["metadata", "mode"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.DeviceMetadata
    mode: ThermostatMode
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ..., mode: _Optional[_Union[ThermostatMode, str]] = ...) -> None: ...

class ThermostatModeSupGetRequest(_message.Message):
    __slots__ = ["metadata"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.DeviceMetadata
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ...) -> None: ...

class ThermostatModeSupGetResponse(_message.Message):
    __slots__ = ["modes"]
    MODES_FIELD_NUMBER: _ClassVar[int]
    modes: _containers.RepeatedScalarFieldContainer[ThermostatMode]
    def __init__(self, modes: _Optional[_Iterable[_Union[ThermostatMode, str]]] = ...) -> None: ...

class ThermostatResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ThermostatSetpoint(_message.Message):
    __slots__ = ["precision", "unit", "value"]
    PRECISION_FIELD_NUMBER: _ClassVar[int]
    UNIT_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    precision: int
    unit: _units_pb2.Unit
    value: float
    def __init__(self, value: _Optional[float] = ..., unit: _Optional[_Union[_units_pb2.Unit, str]] = ..., precision: _Optional[int] = ...) -> None: ...

class ThermostatSetpointRange(_message.Message):
    __slots__ = ["max", "min", "type"]
    MAX_FIELD_NUMBER: _ClassVar[int]
    MIN_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    max: ThermostatSetpoint
    min: ThermostatSetpoint
    type: ThermostatSetpointType
    def __init__(self, type: _Optional[_Union[ThermostatSetpointType, str]] = ..., min: _Optional[_Union[ThermostatSetpoint, _Mapping]] = ..., max: _Optional[_Union[ThermostatSetpoint, _Mapping]] = ...) -> None: ...

class ThermostatSetpointReport(_message.Message):
    __slots__ = ["setpoint"]
    SETPOINT_FIELD_NUMBER: _ClassVar[int]
    setpoint: ThermostatSetpoint
    def __init__(self, setpoint: _Optional[_Union[ThermostatSetpoint, _Mapping]] = ...) -> None: ...

class ThermostatSetpointSetRequest(_message.Message):
    __slots__ = ["metadata", "setpoint", "type"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SETPOINT_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.DeviceMetadata
    setpoint: ThermostatSetpoint
    type: ThermostatSetpointType
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ..., type: _Optional[_Union[ThermostatSetpointType, str]] = ..., setpoint: _Optional[_Union[ThermostatSetpoint, _Mapping]] = ...) -> None: ...

class ThermostatMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class ThermostatSetpointType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class ThermostatFanMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StructureNode(_message.Message):
    __slots__ = ["capabilities", "uuid"]
    CAPABILITIES_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    capabilities: _containers.RepeatedScalarFieldContainer[str]
    uuid: bytes
    def __init__(self, uuid: _Optional[bytes] = ..., capabilities: _Optional[_Iterable[str]] = ...) -> None: ...

class StructureReport(_message.Message):
    __slots__ = ["mac", "nodes", "revision", "type"]
    MAC_FIELD_NUMBER: _ClassVar[int]
    NODES_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    mac: str
    nodes: _containers.RepeatedCompositeFieldContainer[StructureNode]
    revision: str
    type: str
    def __init__(self, mac: _Optional[str] = ..., type: _Optional[str] = ..., revision: _Optional[str] = ..., nodes: _Optional[_Iterable[_Union[StructureNode, _Mapping]]] = ...) -> None: ...

class StructureRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class StructureResponse(_message.Message):
    __slots__ = ["structure"]
    STRUCTURE_FIELD_NUMBER: _ClassVar[int]
    structure: StructureReport
    def __init__(self, structure: _Optional[_Union[StructureReport, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/units.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vemmio_client/units.proto\x12\x08vemmiopb*\xa1\x02\n\x04Unit\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x43\x45LSIUS\x10\x01\x12\x0e\n\nFAHRENHEIT\x10\x02\x12\x07\n\x03LUX\x10\x03\x12\x0e\n\nPERCENTAGE\x10\x04\x12\x08\n\x04WATT\x10\x05\x12\x0f\n\x0bPULSE_COUNT\x10\x06\x12\x07\n\x03KWH\x10\x07\x12\x08\n\x04KVAH\x10\x08\x12\x08\n\x04VOLT\x10\t\x12\n\n\x06\x41MPERE\x10\n\x12\x10\n\x0cPOWER_FACTOR\x10\x0b\x12\x10\n\x0c\x43UBIC_METERS\x10\x0c\x12\x0e\n\nCUBIC_FEET\x10\r\x12\x0e\n\nUS_GALLONS\x10\x0e\x12\x0b\n\x07\x44\x45GREES\x10\x0f\x12\x1c\n\x18METER_PER_SECOND_SQUARED\x10\x10\x12\x0c\n\x08MERCALLI\x10\x11\x12\x15\n\x11PARTS_PER_MILLION\x10\x12\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.units_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _UNIT._serialized_start=40
  _UNIT._serialized_end=329
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AddonAddResponse(_message.Message):
    __slots__ = ["uuid"]
    UUID_FIELD_NUMBER: _ClassVar[int]
    uuid: str
    def __init__(self, uuid: _Optional[str] = ...) -> None: ...

class AddonAddThermostatRequest(_message.Message):
    __slots__ = ["thermostat"]
    THERMOSTAT_FIELD_NUMBER: _ClassVar[int]
    thermostat: AddonThermostat
    def __init__(self, thermostat: _Optional[_Union[AddonThermostat, _Mapping]] = ...) -> None: ...

class AddonListRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class AddonListResponse(_message.Message):
    __slots__ = ["addons"]
    class Addon(_message.Message):
        __slots__ = ["thermostat", "uuid"]
        THERMOSTAT_FIELD_NUMBER: _ClassVar[int]
        UUID_FIELD_NUMBER: _ClassVar[int]
        thermostat: AddonThermostat
        uuid: str
        def __init__(self, uuid: _Optional[str] = ..., thermostat: _Optional[_Union[AddonThermostat, _Mapping]] = ...) -> None: ...
    ADDONS_FIELD_NUMBER: _ClassVar[int]
    addons: _containers.RepeatedCompositeFieldContainer[AddonListResponse.Addon]
    def __init__(self, addons: _Optional[_Iterable[_Union[AddonListResponse.Addon, _Mapping]]] = ...) -> None: ...

class AddonThermostat(_message.Message):
    __slots__ = ["input_filename", "output_filename"]
    INPUT_FILENAME_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FILENAME_FIELD_NUMBER: _ClassVar[int]
    input_filename: str
    output_filename: str
    def __init__(self, input_filename: _Optional[str] = ..., output_filename: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/tamper.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avemmio_client/tamper.proto\x12\x08vemmiopb\"4\n\x0cTamperReport\x12$\n\x05state\x18\x01 \x01(\x0e\x32\x15.vemmiopb.TamperState*R\n\x0bTamperState\x12\x18\n\x14TAMPER_COVER_REMOVED\x10\x00\x12\x17\n\x13TAMPER_INVALID_CODE\x10\x01\x12\x10\n\x0cTAMPER_MOVED\x10\x02\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.tamper_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _TAMPERSTATE._serialized_start=94
  _TAMPERSTATE._serialized_end=176
  _TAMPERREPORT._serialized_start=40
  _TAMPERREPORT._serialized_end=92
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/metadata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cvemmio_client/metadata.proto\x12\x08vemmiopb\"\xf4\x01\n\x0e\x44\x65viceMetadata\x12(\n\x05zwave\x18\x01 \x01(\x0b\x32\x17.vemmiopb.ZWaveMetadataH\x00\x12*\n\x06zigbee\x18\x02 \x01(\x0b\x32\x18.vemmiopb.ZigbeeMetadataH\x00\x12(\n\x05\x61\x64\x64on\x18\x03 \x01(\x0b\x32\x17.vemmiopb.AddonMetadataH\x00\x12(\n\x05\x61lias\x18\x05 \x01(\x0b\x32\x17.vemmiopb.AliasMetadataH\x00\x12&\n\x04mqtt\x18\x06 \x01(\x0b\x32\x16.vemmiopb.MQTTMetadataH\x00\x42\n\n\x08metadataJ\x04\x08\x04\x10\x05\"5\n\rZWaveMetadata\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12\x13\n\x0b\x65ndpoint_id\x18\x02 \x01(\x05\"6\n\x0eZigbeeMetadata\x12\x12\n\neui64_addr\x18\x01 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\x05\"\x1d\n\rAddonMetadata\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"\x1d\n\rAliasMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\"!\n\x0cMQTTMetadata\x12\x11\n\tdevice_id\x18\x01 \x01(\x0c\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.metadata_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _DEVICEMETADATA._serialized_start=43
  _DEVICEMETADATA._serialized_end=287
  _ZWAVEMETADATA._serialized_start=289
  _ZWAVEMETADATA._serialized_end=342
  _ZIGBEEMETADATA._serialized_start=344
  _ZIGBEEMETADATA._serialized_end=398
  _ADDONMETADATA._serialized_start=400
  _ADDONMETADATA._serialized_end=429
  _ALIASMETADATA._serialized_start=431
  _ALIASMETADATA._serialized_end=460
  _MQTTMETADATA._serialized_start=462
  _MQTTMETADATA._serialized_end=495
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

CARBON_DIOXIDE_MAINTENANCE_PERIODIC_INSPECTION: CarbonDioxideMaintenance
CARBON_DIOXIDE_MAINTENANCE_UNSPECIFIED: CarbonDioxideMaintenance
CARBON_DIOXIDE_REPLACEMENT_EOL: CarbonDioxideReplacement
CARBON_DIOXIDE_REPLACEMENT_UNSPECIFIED: CarbonDioxideReplacement
CARBON_DIOXIDE_STATE_CLEAR: CarbonDioxideState
CARBON_DIOXIDE_STATE_DETECTED: CarbonDioxideState
CARBON_DIOXIDE_STATE_MAINTENANCE_REQUIRED: CarbonDioxideState
CARBON_DIOXIDE_STATE_REPLACEMENT_REQUIRED: CarbonDioxideState
CARBON_DIOXIDE_STATE_SILENCED: CarbonDioxideState
CARBON_DIOXIDE_STATE_TEST: CarbonDioxideState
CARBON_DIOXIDE_STATE_UNSPECIFIED: CarbonDioxideState
DESCRIPTOR: _descriptor.FileDescriptor

class CarbonDioxideReport(_message.Message):
    __slots__ = ["maintenance", "replacement", "state"]
    MAINTENANCE_FIELD_NUMBER: _ClassVar[int]
    REPLACEMENT_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    maintenance: CarbonDioxideMaintenance
    replacement: CarbonDioxideReplacement
    state: CarbonDioxideState
    def __init__(self, state: _Optional[_Union[CarbonDioxideState, str]] = ..., replacement: _Optional[_Union[CarbonDioxideReplacement, str]] = ..., maintenance: _Optional[_Union[CarbonDioxideMaintenance, str]] = ...) -> None: ...

class CarbonDioxideState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class CarbonDioxideReplacement(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class CarbonDioxideMaintenance(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DoorbellReport(_message.Message):
    __slots__ = ["state"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ACTIVE: DoorbellReport.State
    CLEAR: DoorbellReport.State
    STATE_FIELD_NUMBER: _ClassVar[int]
    state: DoorbellReport.State
    def __init__(self, state: _Optional[_Union[DoorbellReport.State, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/carbon_monoxide.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2
from vemmio_client import units_pb2 as vemmio__client_dot_units__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#vemmio_client/carbon_monoxide.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\x1a\x19vemmio_client/units.proto\"F\n\x18\x43\x61rbonMonoxideGetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"H\n\x19\x43\x61rbonMonoxideGetResponse\x12\x1c\n\x04unit\x18\x01 \x01(\x0e\x32\x0e.vemmiopb.Unit\x12\r\n\x05value\x18\x02 \x01(\x01\"H\n\x19\x43\x61rbonMonoxideValueReport\x12\x1c\n\x04unit\x18\x01 \x01(\x0e\x32\x0e.vemmiopb.Unit\x12\r\n\x05value\x18\x02 \x01(\x01\"\xbd\x01\n\x19\x43\x61rbonMonoxideStateReport\x12,\n\x05state\x18\x01 \x01(\x0e\x32\x1d.vemmiopb.CarbonMonoxideState\x12\x38\n\x0breplacement\x18\x02 \x01(\x0e\x32#.vemmiopb.CarbonMonoxideReplacement\x12\x38\n\x0bmaintenance\x18\x03 \x01(\x0e\x32#.vemmiopb.CarbonMonoxideMaintenance*\xa5\x02\n\x13\x43\x61rbonMonoxideState\x12%\n!CARBON_MONOXIDE_STATE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x43\x41RBON_MONOXIDE_STATE_CLEAR\x10\x01\x12\"\n\x1e\x43\x41RBON_MONOXIDE_STATE_DETECTED\x10\x02\x12\x1e\n\x1a\x43\x41RBON_MONOXIDE_STATE_TEST\x10\x03\x12\"\n\x1e\x43\x41RBON_MONOXIDE_STATE_SILENCED\x10\x04\x12.\n*CARBON_MONOXIDE_STATE_REPLACEMENT_REQUIRED\x10\x05\x12.\n*CARBON_MONOXIDE_STATE_MAINTENANCE_REQUIRED\x10\x06*m\n\x19\x43\x61rbonMonoxideReplacement\x12+\n\'CARBON_MONOXIDE_REPLACEMENT_UNSPECIFIED\x10\x00\x12#\n\x1f\x43\x41RBON_MONOXIDE_REPLACEMENT_EOL\x10\x01*}\n\x19\x43\x61rbonMonoxideMaintenance\x12+\n\'CARBON_MONOXIDE_MAINTENANCE_UNSPECIFIED\x10\x00\x12\x33\n/CARBON_MONOXIDE_MAINTENANCE_PERIODIC_INSPECTION\x10\x01\x32u\n\x15\x43\x61rbonMonoxideService\x12\\\n\x11\x43\x61rbonMonoxideGet\x12\".vemmiopb.CarbonMonoxideGetRequest\x1a#.vemmiopb.CarbonMonoxideGetResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.carbon_monoxide_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _CARBONMONOXIDESTATE._serialized_start=519
  _CARBONMONOXIDESTATE._serialized_end=812
  _CARBONMONOXIDEREPLACEMENT._serialized_start=814
  _CARBONMONOXIDEREPLACEMENT._serialized_end=923
  _CARBONMONOXIDEMAINTENANCE._serialized_start=925
  _CARBONMONOXIDEMAINTENANCE._serialized_end=1050
  _CARBONMONOXIDEGETREQUEST._serialized_start=106
  _CARBONMONOXIDEGETREQUEST._serialized_end=176
  _CARBONMONOXIDEGETRESPONSE._serialized_start=178
  _CARBONMONOXIDEGETRESPONSE._serialized_end=250
  _CARBONMONOXIDEVALUEREPORT._serialized_start=252
  _CARBONMONOXIDEVALUEREPORT._serialized_end=324
  _CARBONMONOXIDESTATEREPORT._serialized_start=327
  _CARBONMONOXIDESTATEREPORT._serialized_end=516
  _CARBONMONOXIDESERVICE._serialized_start=1052
  _CARBONMONOXIDESERVICE._serialized_end=1169
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

BSENSOR_STATE_EVENT_DETECTED: BinarySensorState
BSENSOR_STATE_IDLE: BinarySensorState
DESCRIPTOR: _descriptor.FileDescriptor
OPEN_CLOSE_STATE_CLOSED: OpenCloseState
OPEN_CLOSE_STATE_OPEN: OpenCloseState

class MotionReport(_message.Message):
    __slots__ = ["state"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    DETECTED: MotionReport.State
    IDLE: MotionReport.State
    STATE_FIELD_NUMBER: _ClassVar[int]
    state: MotionReport.State
    def __init__(self, state: _Optional[_Union[MotionReport.State, str]] = ...) -> None: ...

class OpenCloseReport(_message.Message):
    __slots__ = ["state"]
    STATE_FIELD_NUMBER: _ClassVar[int]
    state: OpenCloseState
    def __init__(self, state: _Optional[_Union[OpenCloseState, str]] = ...) -> None: ...

class OpenCloseState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class BinarySensorState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/devices.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import accelerometer_pb2 as vemmio__client_dot_accelerometer__pb2
from vemmio_client import color_pb2 as vemmio__client_dot_color__pb2
from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2
from vemmio_client import power_source_pb2 as vemmio__client_dot_power__source__pb2
from vemmio_client import thermostat_pb2 as vemmio__client_dot_thermostat__pb2
from vemmio_client import units_pb2 as vemmio__client_dot_units__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bvemmio_client/devices.proto\x12\x08vemmiopb\x1a!vemmio_client/accelerometer.proto\x1a\x19vemmio_client/color.proto\x1a\x1cvemmio_client/metadata.proto\x1a vemmio_client/power_source.proto\x1a\x1evemmio_client/thermostat.proto\x1a\x19vemmio_client/units.proto\"\x14\n\x12\x44\x65vicesListRequest\"8\n\x13\x44\x65vicesListResponse\x12!\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x10.vemmiopb.Device\"\xbf\x02\n\x06\x44\x65vice\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x08metadata\x18\x02 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12*\n\x0c\x63\x61pabilities\x18\x03 \x03(\x0b\x32\x14.vemmiopb.Capability\x12\x0c\n\x04i18n\x18\x04 \x01(\t\x12%\n\x05group\x18\x05 \x01(\x0e\x32\x16.vemmiopb.Device.Group\"\x99\x01\n\x05Group\x12\t\n\x05OTHER\x10\x00\x12\x0b\n\x07\x43LIMATE\x10\x01\x12\x0c\n\x08SECURITY\x10\x02\x12\t\n\x05POWER\x10\x03\x12\x13\n\x0fROLLER_SHUTTERS\x10\x04\x12\x0b\n\x07\x43\x41MERAS\x10\x05\x12\r\n\tDOORBELLS\x10\x06\x12\x0c\n\x08GATEWAYS\x10\x07\x12\n\n\x06LIGHTS\x10\x08\x12\t\n\x05GATES\x10\t\x12\t\n\x05SOUND\x10\n\"\xf5\r\n\nCapability\x12,\n\x06switch\x18\x01 \x01(\x0b\x32\x1a.vemmiopb.SwitchCapabilityH\x00\x12\x30\n\x0bpower_meter\x18\x02 \x01(\x0b\x32\x19.vemmiopb.MeterCapabilityH\x00\x12.\n\tgas_meter\x18\x03 \x01(\x0b\x32\x19.vemmiopb.MeterCapabilityH\x00\x12\x30\n\x0bwater_meter\x18\x04 \x01(\x0b\x32\x19.vemmiopb.MeterCapabilityH\x00\x12\x33\n\nopen_close\x18\x05 \x01(\x0b\x32\x1d.vemmiopb.OpenCloseCapabilityH\x00\x12;\n\x0esmoke_detector\x18\x06 \x01(\x0b\x32!.vemmiopb.SmokeDetectorCapabilityH\x00\x12=\n\x0fmotion_detector\x18\x07 \x01(\x0b\x32\".vemmiopb.MotionDetectorCapabilityH\x00\x12;\n\x0e\x66lood_detector\x18\x08 \x01(\x0b\x32!.vemmiopb.FloodDetectorCapabilityH\x00\x12N\n\x18\x63\x61rbon_monoxide_detector\x18\t \x01(\x0b\x32*.vemmiopb.CarbonMonoxideDetectorCapabilityH\x00\x12\x34\n\nthermostat\x18\n \x01(\x0b\x32\x1e.vemmiopb.ThermostatCapabilityH\x00\x12\x36\n\x0btemperature\x18\x0b \x01(\x0b\x32\x1f.vemmiopb.TemperatureCapabilityH\x00\x12\x30\n\x08humidity\x18\x0c \x01(\x0b\x32\x1c.vemmiopb.HumidityCapabilityH\x00\x12\x38\n\x0cillumination\x18\r \x01(\x0b\x32 .vemmiopb.IlluminationCapabilityH\x00\x12\x32\n\tdirection\x18\x0e \x01(\x0b\x32\x1d.vemmiopb.DirectionCapabilityH\x00\x12,\n\x06tamper\x18\x0f \x01(\x0b\x32\x1a.vemmiopb.TamperCapabilityH\x00\x12\x32\n\temergency\x18\x10 \x01(\x0b\x32\x1d.vemmiopb.EmergencyCapabilityH\x00\x12(\n\x04\x64oor\x18\x11 \x01(\x0b\x32\x18.vemmiopb.DoorCapabilityH\x00\x12-\n\x07tap_tap\x18\x12 \x01(\x0b\x32\x1a.vemmiopb.TapTapCapabilityH\x00\x12*\n\x05\x63olor\x18\x13 \x01(\x0b\x32\x19.vemmiopb.ColorCapabilityH\x00\x12*\n\x05level\x18\x14 \x01(\x0b\x32\x19.vemmiopb.LevelCapabilityH\x00\x12.\n\x07\x62\x61ttery\x18\x15 \x01(\x0b\x32\x1b.vemmiopb.BatteryCapabilityH\x00\x12(\n\x04lock\x18\x16 \x01(\x0b\x32\x18.vemmiopb.LockCapabilityH\x00\x12,\n\x06remote\x18\x17 \x01(\x0b\x32\x1a.vemmiopb.RemoteCapabilityH\x00\x12\x37\n\x0cpower_source\x18\x18 \x01(\x0b\x32\x1f.vemmiopb.PowerSourceCapabilityH\x00\x12;\n\x0eroller_shutter\x18\x19 \x01(\x0b\x32!.vemmiopb.RollerShutterCapabilityH\x00\x12:\n\rconfiguration\x18\x1a \x01(\x0b\x32!.vemmiopb.ConfigurationCapabilityH\x00\x12\x30\n\x08\x64oorbell\x18\x1b \x01(\x0b\x32\x1c.vemmiopb.DoorbellCapabilityH\x00\x12*\n\x05siren\x18\x1c \x01(\x0b\x32\x19.vemmiopb.SirenCapabilityH\x00\x12:\n\raccelerometer\x18\x1d \x01(\x0b\x32!.vemmiopb.AccelerometerCapabilityH\x00\x12.\n\x07seismic\x18\x1e \x01(\x0b\x32\x1b.vemmiopb.SeismicCapabilityH\x00\x12L\n\x17\x63\x61rbon_dioxide_detector\x18\x1f \x01(\x0b\x32).vemmiopb.CarbonDioxideDetectorCapabilityH\x00\x12.\n\x07voltage\x18  \x01(\x0b\x32\x1b.vemmiopb.VoltageCapabilityH\x00\x12\x36\n\x0bultraviolet\x18! \x01(\x0b\x32\x1f.vemmiopb.UltravioletCapabilityH\x00\x42\x0c\n\ncapability\"\x12\n\x10SwitchCapability\"?\n\x0fMeterCapability\x12\x1d\n\x05units\x18\x01 \x03(\x0e\x32\x0e.vemmiopb.Unit\x12\r\n\x05reset\x18\x02 \x01(\x08\"\x15\n\x13OpenCloseCapability\"\x19\n\x17SmokeDetectorCapability\"\x1a\n\x18MotionDetectorCapability\"\x19\n\x17\x46loodDetectorCapability\"A\n CarbonMonoxideDetectorCapability\x12\x1d\n\x05units\x18\x01 \x03(\x0e\x32\x0e.vemmiopb.Unit\"!\n\x1f\x43\x61rbonDioxideDetectorCapability\"I\n\x14ThermostatCapability\x12\x31\n\x06ranges\x18\x01 \x03(\x0b\x32!.vemmiopb.ThermostatSetpointRange\"6\n\x15TemperatureCapability\x12\x1d\n\x05units\x18\x01 \x03(\x0e\x32\x0e.vemmiopb.Unit\"3\n\x12HumidityCapability\x12\x1d\n\x05units\x18\x01 \x03(\x0e\x32\x0e.vemmiopb.Unit\"7\n\x16IlluminationCapability\x12\x1d\n\x05units\x18\x01 \x03(\x0e\x32\x0e.vemmiopb.Unit\"4\n\x13\x44irectionCapability\x12\x1d\n\x05units\x18\x01 \x03(\x0e\x32\x0e.vemmiopb.Unit\"\x12\n\x10TamperCapability\"\x15\n\x13\x45mergencyCapability\"\x10\n\x0e\x44oorCapability\"\x12\n\x10TapTapCapability\"?\n\x0f\x43olorCapability\x12,\n\ncomponents\x18\x01 \x03(\x0e\x32\x18.vemmiopb.ColorComponent\"\x11\n\x0fLevelCapability\"\x13\n\x11\x42\x61tteryCapability\"\x10\n\x0eLockCapability\"\x12\n\x10RemoteCapability\"C\n\x15PowerSourceCapability\x12*\n\x06\x65vents\x18\x01 \x03(\x0e\x32\x1a.vemmiopb.PowerSourceEvent\"\x19\n\x17RollerShutterCapability\"\x19\n\x17\x43onfigurationCapability\"\x14\n\x12\x44oorbellCapability\"\x11\n\x0fSirenCapability\"\xa1\x01\n\x17\x41\x63\x63\x65lerometerCapability\x12\x34\n\x04\x61xes\x18\x01 \x03(\x0b\x32&.vemmiopb.AccelerometerCapability.Axis\x1aP\n\x04\x41xis\x12)\n\x04\x61xis\x18\x01 \x01(\x0e\x32\x1b.vemmiopb.AccelerometerAxis\x12\x1d\n\x05units\x18\x02 \x03(\x0e\x32\x0e.vemmiopb.Unit\"Y\n\x11SeismicCapability\x12!\n\tintensity\x18\x01 \x03(\x0e\x32\x0e.vemmiopb.Unit\x12!\n\tmagnitude\x18\x02 \x03(\x0e\x32\x0e.vemmiopb.Unit\"2\n\x11VoltageCapability\x12\x1d\n\x05units\x18\x01 \x03(\x0e\x32\x0e.vemmiopb.Unit\"6\n\x15UltravioletCapability\x12\x1d\n\x05units\x18\x01 \x03(\x0e\x32\x0e.vemmiopb.Unit2U\n\x07\x44\x65vices\x12J\n\x0b\x44\x65vicesList\x12\x1c.vemmiopb.DevicesListRequest\x1a\x1d.vemmiopb.DevicesListResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.devices_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _DEVICESLISTREQUEST._serialized_start=226
  _DEVICESLISTREQUEST._serialized_end=246
  _DEVICESLISTRESPONSE._serialized_start=248
  _DEVICESLISTRESPONSE._serialized_end=304
  _DEVICE._serialized_start=307
  _DEVICE._serialized_end=626
  _DEVICE_GROUP._serialized_start=473
  _DEVICE_GROUP._serialized_end=626
  _CAPABILITY._serialized_start=629
  _CAPABILITY._serialized_end=2410
  _SWITCHCAPABILITY._serialized_start=2412
  _SWITCHCAPABILITY._serialized_end=2430
  _METERCAPABILITY._serialized_start=2432
  _METERCAPABILITY._serialized_end=2495
  _OPENCLOSECAPABILITY._serialized_start=2497
  _OPENCLOSECAPABILITY._serialized_end=2518
  _SMOKEDETECTORCAPABILITY._serialized_start=2520
  _SMOKEDETECTORCAPABILITY._serialized_end=2545
  _MOTIONDETECTORCAPABILITY._serialized_start=2547
  _MOTIONDETECTORCAPABILITY._serialized_end=2573
  _FLOODDETECTORCAPABILITY._serialized_start=2575
  _FLOODDETECTORCAPABILITY._serialized_end=2600
  _CARBONMONOXIDEDETECTORCAPABILITY._serialized_start=2602
  _CARBONMONOXIDEDETECTORCAPABILITY._serialized_end=2667
  _CARBONDIOXIDEDETECTORCAPABILITY._serialized_start=2669
  _CARBONDIOXIDEDETECTORCAPABILITY._serialized_end=2702
  _THERMOSTATCAPABILITY._serialized_start=2704
  _THERMOSTATCAPABILITY._serialized_end=2777
  _TEMPERATURECAPABILITY._serialized_start=2779
  _TEMPERATURECAPABILITY._serialized_end=2833
  _HUMIDITYCAPABILITY._serialized_start=2835
  _HUMIDITYCAPABILITY._serialized_end=2886
  _ILLUMINATIONCAPABILITY._serialized_start=2888
  _ILLUMINATIONCAPABILITY._serialized_end=2943
  _DIRECTIONCAPABILITY._serialized_start=2945
  _DIRECTIONCAPABILITY._serialized_end=2997
  _TAMPERCAPABILITY._serialized_start=2999
  _TAMPERCAPABILITY._serialized_end=3017
  _EMERGENCYCAPABILITY._serialized_start=3019
  _EMERGENCYCAPABILITY._serialized_end=3040
  _DOORCAPABILITY._serialized_start=3042
  _DOORCAPABILITY._serialized_end=3058
  _TAPTAPCAPABILITY._serialized_start=3060
  _TAPTAPCAPABILITY._serialized_end=3078
  _COLORCAPABILITY._serialized_start=3080
  _COLORCAPABILITY._serialized_end=3143
  _LEVELCAPABILITY._serialized_start=3145
  _LEVELCAPABILITY._serialized_end=3162
  _BATTERYCAPABILITY._serialized_start=3164
  _BATTERYCAPABILITY._serialized_end=3183
  _LOCKCAPABILITY._serialized_start=3185
  _LOCKCAPABILITY._serialized_end=3201
  _REMOTECAPABILITY._serialized_start=3203
  _REMOTECAPABILITY._serialized_end=3221
  _POWERSOURCECAPABILITY._serialized_start=3223
  _POWERSOURCECAPABILITY._serialized_end=3290
  _ROLLERSHUTTERCAPABILITY._serialized_start=3292
  _ROLLERSHUTTERCAPABILITY._serialized_end=3317
  _CONFIGURATIONCAPABILITY._serialized_start=3319
  _CONFIGURATIONCAPABILITY._serialized_end=3344
  _DOORBELLCAPABILITY._serialized_start=3346
  _DOORBELLCAPABILITY._serialized_end=3366
  _SIRENCAPABILITY._serialized_start=3368
  _SIRENCAPABILITY._serialized_end=3385
  _ACCELEROMETERCAPABILITY._serialized_start=3388
  _ACCELEROMETERCAPABILITY._serialized_end=3549
  _ACCELEROMETERCAPABILITY_AXIS._serialized_start=3469
  _ACCELEROMETERCAPABILITY_AXIS._serialized_end=3549
  _SEISMICCAPABILITY._serialized_start=3551
  _SEISMICCAPABILITY._serialized_end=3640
  _VOLTAGECAPABILITY._serialized_start=3642
  _VOLTAGECAPABILITY._serialized_end=3692
  _ULTRAVIOLETCAPABILITY._serialized_start=3694
  _ULTRAVIOLETCAPABILITY._serialized_end=3748
  _DEVICES._serialized_start=3750
  _DEVICES._serialized_end=3835
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/messaging.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvemmio_client/messaging.proto\x12\x08vemmiopb\"C\n\x0c\x45mailMessage\x12\x11\n\trecipient\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"`\n\x0bPushMessage\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x62\x61\x64ge\x18\x03 \x01(\x05\x12\x0f\n\x07site_id\x18\x04 \x01(\t\x12\x11\n\tsite_name\x18\x05 \x01(\tB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.messaging_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _EMAILMESSAGE._serialized_start=43
  _EMAILMESSAGE._serialized_end=110
  _PUSHMESSAGE._serialized_start=112
  _PUSHMESSAGE._serialized_end=208
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/structure.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvemmio_client/structure.proto\x12\x08vemmiopb\"\x12\n\x10StructureRequest\"A\n\x11StructureResponse\x12,\n\tstructure\x18\x01 \x01(\x0b\x32\x19.vemmiopb.StructureReport\"f\n\x0fStructureReport\x12\x0b\n\x03mac\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x10\n\x08revision\x18\x03 \x01(\t\x12&\n\x05nodes\x18\x04 \x03(\x0b\x32\x17.vemmiopb.StructureNode\"3\n\rStructureNode\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\x14\n\x0c\x63\x61pabilities\x18\x02 \x03(\t2[\n\x10StructureService\x12G\n\x0cGetStructure\x12\x1a.vemmiopb.StructureRequest\x1a\x1b.vemmiopb.StructureResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.structure_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _STRUCTUREREQUEST._serialized_start=43
  _STRUCTUREREQUEST._serialized_end=61
  _STRUCTURERESPONSE._serialized_start=63
  _STRUCTURERESPONSE._serialized_end=128
  _STRUCTUREREPORT._serialized_start=130
  _STRUCTUREREPORT._serialized_end=232
  _STRUCTURENODE._serialized_start=234
  _STRUCTURENODE._serialized_end=285
  _STRUCTURESERVICE._serialized_start=287
  _STRUCTURESERVICE._serialized_end=378
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/emergency.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvemmio_client/emergency.proto\x12\x08vemmiopb\"8\n\x0f\x45mergencyReport\x12%\n\x04type\x18\x01 \x01(\x0e\x32\x17.vemmiopb.EmergencyType*P\n\rEmergencyType\x12\x14\n\x10\x45MERGENCY_POLICE\x10\x00\x12\x12\n\x0e\x45MERGENCY_FIRE\x10\x01\x12\x15\n\x11\x45MERGENCY_MEDICAL\x10\x02\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.emergency_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _EMERGENCYTYPE._serialized_start=101
  _EMERGENCYTYPE._serialized_end=181
  _EMERGENCYREPORT._serialized_start=43
  _EMERGENCYREPORT._serialized_end=99
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
DOOR_EVENT_HARD_KNOCK: DoorEvent
DOOR_EVENT_INTRUSION: DoorEvent
DOOR_EVENT_KNOCK: DoorEvent

class DoorReport(_message.Message):
    __slots__ = ["event"]
    EVENT_FIELD_NUMBER: _ClassVar[int]
    event: DoorEvent
    def __init__(self, event: _Optional[_Union[DoorEvent, str]] = ...) -> None: ...

class DoorEvent(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/smoke.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vemmio_client/smoke.proto\x12\x08vemmiopb\"\xac\x01\n\x0bSmokeReport\x12+\n\x05state\x18\x01 \x01(\x0e\x32\x1c.vemmiopb.SmokeDetectorState\x12\x37\n\x0breplacement\x18\x02 \x01(\x0e\x32\".vemmiopb.SmokeDetectorReplacement\x12\x37\n\x0bmaintenance\x18\x03 \x01(\x0e\x32\".vemmiopb.SmokeDetectorMaintenance*\xde\x01\n\x12SmokeDetectorState\x12\x1b\n\x17SMOKE_STATE_UNSPECIFIED\x10\x00\x12\x15\n\x11SMOKE_STATE_CLEAR\x10\x01\x12\x18\n\x14SMOKE_STATE_DETECTED\x10\x02\x12\x14\n\x10SMOKE_STATE_TEST\x10\x03\x12\x18\n\x14SMOKE_STATE_SILENCED\x10\x04\x12$\n SMOKE_STATE_REPLACEMENT_REQUIRED\x10\x05\x12$\n SMOKE_STATE_MAINTENANCE_REQUIRED\x10\x06*X\n\x18SmokeDetectorReplacement\x12!\n\x1dSMOKE_REPLACEMENT_UNSPECIFIED\x10\x00\x12\x19\n\x15SMOKE_REPLACEMENT_EOL\x10\x01*\x8e\x01\n\x18SmokeDetectorMaintenance\x12!\n\x1dSMOKE_MAINTENANCE_UNSPECIFIED\x10\x00\x12)\n%SMOKE_MAINTENANCE_PERIODIC_INSPECTION\x10\x01\x12$\n SMOKE_MAINTENANCE_DUST_IN_DEVICE\x10\x02\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.smoke_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _SMOKEDETECTORSTATE._serialized_start=215
  _SMOKEDETECTORSTATE._serialized_end=437
  _SMOKEDETECTORREPLACEMENT._serialized_start=439
  _SMOKEDETECTORREPLACEMENT._serialized_end=527
  _SMOKEDETECTORMAINTENANCE._serialized_start=530
  _SMOKEDETECTORMAINTENANCE._serialized_end=672
  _SMOKEREPORT._serialized_start=40
  _SMOKEREPORT._serialized_end=212
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/firmware.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cvemmio_client/firmware.proto\x12\x08vemmiopb\",\n\rFirmwareChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\r\n\x05index\x18\x02 \x01(\x05\"$\n\x10\x46irmwareChunkAck\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\":\n\x16\x46irmwareUpgradeRequest\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0e\n\x06sha256\x18\x02 \x01(\t\"\x14\n\x12\x46irmwareUpgradeAck\"(\n\x15\x46irmwareUpdateRequest\x12\x0f\n\x07version\x18\x01 \x01(\t\"\x18\n\x16\x46irmwareUpdateResponse\"\x1e\n\x1c\x46irmwareLatestVersionRequest\"0\n\x1d\x46irmwareLatestVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\"o\n\x1a\x46irmwareUpdateStatusReport\x12.\n\x06status\x18\x01 \x01(\x0e\x32\x1e.vemmiopb.FirmwareUpdateStatus\x12\x10\n\x08progress\x18\x02 \x01(\r\x12\x0f\n\x07version\x18\x03 \x01(\t*\xd1\x01\n\x14\x46irmwareUpdateStatus\x12\"\n\x1e\x46IRMWARE_UPDATE_STATUS_UNKNOWN\x10\x00\x12&\n\"FIRMWARE_UPDATE_STATUS_IN_PROGRESS\x10\x01\x12#\n\x1f\x46IRMWARE_UPDATE_STATUS_COMPLETE\x10\x02\x12!\n\x1d\x46IRMWARE_UPDATE_STATUS_FAILED\x10\x03\x12%\n!FIRMWARE_UPDATE_STATUS_UP_TO_DATE\x10\x04\x32\xac\x01\n\x08\x46irmware\x12I\n\x0e\x46irmwareUpload\x12\x17.vemmiopb.FirmwareChunk\x1a\x1a.vemmiopb.FirmwareChunkAck(\x01\x30\x01\x12U\n\x0f\x46irmwareUpgrade\x12 .vemmiopb.FirmwareUpgradeRequest\x1a\x1c.vemmiopb.FirmwareUpgradeAck(\x01\x30\x01\x32\xd0\x01\n\x0f\x46irmwareService\x12S\n\x0e\x46irmwareUpdate\x12\x1f.vemmiopb.FirmwareUpdateRequest\x1a .vemmiopb.FirmwareUpdateResponse\x12h\n\x15\x46irmwareLatestVersion\x12&.vemmiopb.FirmwareLatestVersionRequest\x1a\'.vemmiopb.FirmwareLatestVersionResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.firmware_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _FIRMWAREUPDATESTATUS._serialized_start=472
  _FIRMWAREUPDATESTATUS._serialized_end=681
  _FIRMWARECHUNK._serialized_start=42
  _FIRMWARECHUNK._serialized_end=86
  _FIRMWARECHUNKACK._serialized_start=88
  _FIRMWARECHUNKACK._serialized_end=124
  _FIRMWAREUPGRADEREQUEST._serialized_start=126
  _FIRMWAREUPGRADEREQUEST._serialized_end=184
  _FIRMWAREUPGRADEACK._serialized_start=186
  _FIRMWAREUPGRADEACK._serialized_end=206
  _FIRMWAREUPDATEREQUEST._serialized_start=208
  _FIRMWAREUPDATEREQUEST._serialized_end=248
  _FIRMWAREUPDATERESPONSE._serialized_start=250
  _FIRMWAREUPDATERESPONSE._serialized_end=274
  _FIRMWARELATESTVERSIONREQUEST._serialized_start=276
  _FIRMWARELATESTVERSIONREQUEST._serialized_end=306
  _FIRMWARELATESTVERSIONRESPONSE._serialized_start=308
  _FIRMWARELATESTVERSIONRESPONSE._serialized_end=356
  _FIRMWAREUPDATESTATUSREPORT._serialized_start=358
  _FIRMWAREUPDATESTATUSREPORT._serialized_end=469
  _FIRMWARE._serialized_start=684
  _FIRMWARE._serialized_end=856
  _FIRMWARESERVICE._serialized_start=859
  _FIRMWARESERVICE._serialized_end=1067
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/sensor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import units_pb2 as vemmio__client_dot_units__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avemmio_client/sensor.proto\x12\x08vemmiopb\x1a\x19vemmio_client/units.proto\"=\n\x0eHumidityReport\x12\x1c\n\x04unit\x18\x01 \x01(\x0e\x32\x0e.vemmiopb.Unit\x12\r\n\x05value\x18\x02 \x01(\x01\"A\n\x12IlluminationReport\x12\x1c\n\x04unit\x18\x01 \x01(\x0e\x32\x0e.vemmiopb.Unit\x12\r\n\x05value\x18\x02 \x01(\x01\">\n\x0f\x44irectionReport\x12\x1c\n\x04unit\x18\x01 \x01(\x0e\x32\x0e.vemmiopb.Unit\x12\r\n\x05value\x18\x02 \x01(\x05\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.sensor_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _HUMIDITYREPORT._serialized_start=67
  _HUMIDITYREPORT._serialized_end=128
  _ILLUMINATIONREPORT._serialized_start=130
  _ILLUMINATIONREPORT._serialized_end=195
  _DIRECTIONREPORT._serialized_start=197
  _DIRECTIONREPORT._serialized_end=259
# @@protoc_insertion_point(module_scope)



from vemmio_client import metadata_pb2 as _metadata_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
SWITCH_OFF: SwitchValue
SWITCH_ON: SwitchValue
SWITCH_UNKNOWN: SwitchValue

class SwitchReport(_message.Message):
    __slots__ = ["value"]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: SwitchValue
    def __init__(self, value: _Optional[_Union[SwitchValue, str]] = ...) -> None: ...

class SwitchRequest(_message.Message):
    __slots__ = ["metadata"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.DeviceMetadata
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ...) -> None: ...

class SwitchResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class SwitchValue(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
EMERGENCY_FIRE: EmergencyType
EMERGENCY_MEDICAL: EmergencyType
EMERGENCY_POLICE: EmergencyType

class EmergencyReport(_message.Message):
    __slots__ = ["type"]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    type: EmergencyType
    def __init__(self, type: _Optional[_Union[EmergencyType, str]] = ...) -> None: ...

class EmergencyType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/admin.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vemmio_client/admin.proto\x12\x08vemmiopb\"\x12\n\x10WalkNodesRequest\"!\n\x11WalkNodesResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\",\n\x0bLogsRequest\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"\x19\n\tLogsChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x32\xc5\x01\n\x05\x41\x64min\x12\x46\n\tWalkNodes\x12\x1a.vemmiopb.WalkNodesRequest\x1a\x1b.vemmiopb.WalkNodesResponse0\x01\x12\x38\n\x08ReadLogs\x12\x15.vemmiopb.LogsRequest\x1a\x13.vemmiopb.LogsChunk0\x01\x12:\n\nFollowLogs\x12\x15.vemmiopb.LogsRequest\x1a\x13.vemmiopb.LogsChunk0\x01\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.admin_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _WALKNODESREQUEST._serialized_start=39
  _WALKNODESREQUEST._serialized_end=57
  _WALKNODESRESPONSE._serialized_start=59
  _WALKNODESRESPONSE._serialized_end=92
  _LOGSREQUEST._serialized_start=94
  _LOGSREQUEST._serialized_end=138
  _LOGSCHUNK._serialized_start=140
  _LOGSCHUNK._serialized_end=165
  _ADMIN._serialized_start=168
  _ADMIN._serialized_end=365
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/gateway.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bvemmio_client/gateway.proto\x12\x08vemmiopb\"\x0f\n\rRebootRequest\"\x10\n\x0eRebootResponse\"\x1e\n\x0eRestartRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x11\n\x0fRestartResponse\"\x10\n\x0eSupportRequest\"\x11\n\x0fSupportResponse2\x8f\x02\n\x07Gateway\x12;\n\x06Reboot\x12\x17.vemmiopb.RebootRequest\x1a\x18.vemmiopb.RebootResponse\x12>\n\x07Restart\x12\x18.vemmiopb.RestartRequest\x1a\x19.vemmiopb.RestartResponse\x12\x43\n\x0cStartSupport\x12\x18.vemmiopb.SupportRequest\x1a\x19.vemmiopb.SupportResponse\x12\x42\n\x0bStopSupport\x12\x18.vemmiopb.SupportRequest\x1a\x19.vemmiopb.SupportResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.gateway_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _REBOOTREQUEST._serialized_start=41
  _REBOOTREQUEST._serialized_end=56
  _REBOOTRESPONSE._serialized_start=58
  _REBOOTRESPONSE._serialized_end=74
  _RESTARTREQUEST._serialized_start=76
  _RESTARTREQUEST._serialized_end=106
  _RESTARTRESPONSE._serialized_start=108
  _RESTARTRESPONSE._serialized_end=125
  _SUPPORTREQUEST._serialized_start=127
  _SUPPORTREQUEST._serialized_end=143
  _SUPPORTRESPONSE._serialized_start=145
  _SUPPORTRESPONSE._serialized_end=162
  _GATEWAY._serialized_start=165
  _GATEWAY._serialized_end=436
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/doorbell.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cvemmio_client/doorbell.proto\x12\x08vemmiopb\"_\n\x0e\x44oorbellReport\x12-\n\x05state\x18\x01 \x01(\x0e\x32\x1e.vemmiopb.DoorbellReport.State\"\x1e\n\x05State\x12\t\n\x05\x43LEAR\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.doorbell_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _DOORBELLREPORT._serialized_start=42
  _DOORBELLREPORT._serialized_end=137
  _DOORBELLREPORT_STATE._serialized_start=107
  _DOORBELLREPORT_STATE._serialized_end=137
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/zigbee.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import devices_pb2 as vemmio__client_dot_devices__pb2
from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avemmio_client/zigbee.proto\x12\x08vemmiopb\x1a\x1bvemmio_client/devices.proto\x1a\x1cvemmio_client/metadata.proto\"\x16\n\x14ZigbeeIncludeRequest\":\n\x15ZigbeeIncludeResponse\x12!\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x10.vemmiopb.Device\"B\n\x14ZigbeeExcludeRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.ZigbeeMetadata\"\x17\n\x15ZigbeeExcludeResponse\"\x14\n\x12ZigbeeNodesRequest\":\n\x13ZigbeeNodesResponse\x12#\n\x05nodes\x18\x01 \x03(\x0b\x32\x14.vemmiopb.ZigbeeNode\"W\n\nZigbeeNode\x12\x11\n\tieee_addr\x18\x01 \x01(\x05\x12\x12\n\neui64_addr\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\x05\x12\x10\n\x08\x63lusters\x18\x04 \x03(\x05\x32\xfb\x01\n\x06Zigbee\x12P\n\rZigbeeInclude\x12\x1e.vemmiopb.ZigbeeIncludeRequest\x1a\x1f.vemmiopb.ZigbeeIncludeResponse\x12P\n\rZigbeeExclude\x12\x1e.vemmiopb.ZigbeeExcludeRequest\x1a\x1f.vemmiopb.ZigbeeExcludeResponse\x12M\n\x0eZigbeeGetNodes\x12\x1c.vemmiopb.ZigbeeNodesRequest\x1a\x1d.vemmiopb.ZigbeeNodesResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.zigbee_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _ZIGBEEINCLUDEREQUEST._serialized_start=99
  _ZIGBEEINCLUDEREQUEST._serialized_end=121
  _ZIGBEEINCLUDERESPONSE._serialized_start=123
  _ZIGBEEINCLUDERESPONSE._serialized_end=181
  _ZIGBEEEXCLUDEREQUEST._serialized_start=183
  _ZIGBEEEXCLUDEREQUEST._serialized_end=249
  _ZIGBEEEXCLUDERESPONSE._serialized_start=251
  _ZIGBEEEXCLUDERESPONSE._serialized_end=274
  _ZIGBEENODESREQUEST._serialized_start=276
  _ZIGBEENODESREQUEST._serialized_end=296
  _ZIGBEENODESRESPONSE._serialized_start=298
  _ZIGBEENODESRESPONSE._serialized_end=356
  _ZIGBEENODE._serialized_start=358
  _ZIGBEENODE._serialized_end=445
  _ZIGBEE._serialized_start=448
  _ZIGBEE._serialized_end=699
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

AC_POWER_LOST: PowerSourceEvent
AC_POWER_RESTORED: PowerSourceEvent
BATTERY_CHARGED: PowerSourceEvent
BATTERY_CHARGING: PowerSourceEvent
BATTERY_CRITICAL: PowerSourceEvent
BATTERY_LOW: PowerSourceEvent
BATTERY_REPLACE_NOW: PowerSourceEvent
BATTERY_REPLACE_SOON: PowerSourceEvent
BROWNOUT_DETECTED: PowerSourceEvent
CLEAR: PowerSourceEvent
DESCRIPTOR: _descriptor.FileDescriptor
LOAD_ERROR: PowerSourceEvent
OVER_CURRENT_DETECTED: PowerSourceEvent
OVER_LOAD_DETECTED: PowerSourceEvent
OVER_VOLTAGE_DETECTED: PowerSourceEvent
POWER_APPLIED: PowerSourceEvent
SURGE_DETECTED: PowerSourceEvent

class PowerSourceReport(_message.Message):
    __slots__ = ["event"]
    EVENT_FIELD_NUMBER: _ClassVar[int]
    event: PowerSourceEvent
    def __init__(self, event: _Optional[_Union[PowerSourceEvent, str]] = ...) -> None: ...

class PowerSourceEvent(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/thermostat.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2
from vemmio_client import units_pb2 as vemmio__client_dot_units__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1evemmio_client/thermostat.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\x1a\x19vemmio_client/units.proto\"n\n\x18ThermostatModeSetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12&\n\x04mode\x18\x02 \x01(\x0e\x32\x18.vemmiopb.ThermostatMode\"I\n\x1bThermostatModeSupGetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"G\n\x1cThermostatModeSupGetResponse\x12\'\n\x05modes\x18\x01 \x03(\x0e\x32\x18.vemmiopb.ThermostatMode\"\xaa\x01\n\x1cThermostatSetpointSetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12.\n\x04type\x18\x02 \x01(\x0e\x32 .vemmiopb.ThermostatSetpointType\x12.\n\x08setpoint\x18\x03 \x01(\x0b\x32\x1c.vemmiopb.ThermostatSetpoint\"x\n\x1bThermostatFanModeSetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12-\n\x08\x66\x61n_mode\x18\x02 \x01(\x0e\x32\x1b.vemmiopb.ThermostatFanMode\"\x14\n\x12ThermostatResponse\">\n\x14ThermostatModeReport\x12&\n\x04mode\x18\x01 \x01(\x0e\x32\x18.vemmiopb.ThermostatMode\"J\n\x18ThermostatSetpointReport\x12.\n\x08setpoint\x18\x01 \x01(\x0b\x32\x1c.vemmiopb.ThermostatSetpoint\"H\n\x17ThermostatFanModeReport\x12-\n\x08\x66\x61n_mode\x18\x01 \x01(\x0e\x32\x1b.vemmiopb.ThermostatFanMode\"\x9f\x01\n\x17ThermostatSetpointRange\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .vemmiopb.ThermostatSetpointType\x12)\n\x03min\x18\x02 \x01(\x0b\x32\x1c.vemmiopb.ThermostatSetpoint\x12)\n\x03max\x18\x03 \x01(\x0b\x32\x1c.vemmiopb.ThermostatSetpoint\"T\n\x12ThermostatSetpoint\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x1c\n\x04unit\x18\x02 \x01(\x0e\x32\x0e.vemmiopb.Unit\x12\x11\n\tprecision\x18\x03 \x01(\r*w\n\x0eThermostatMode\x12\x17\n\x13THERMOSTAT_MODE_OFF\x10\x00\x12\x18\n\x14THERMOSTAT_MODE_HEAT\x10\x01\x12\x18\n\x14THERMOSTAT_MODE_COOL\x10\x02\x12\x18\n\x14THERMOSTAT_MODE_AUTO\x10\x03*\x81\x01\n\x16ThermostatSetpointType\x12!\n\x1dTHERMOSTAT_SETPOINT_TYPE_HEAT\x10\x00\x12!\n\x1dTHERMOSTAT_SETPOINT_TYPE_COOL\x10\x01\x12!\n\x1dTHERMOSTAT_SETPOINT_TYPE_AUTO\x10\x02*\xb0\x01\n\x11ThermostatFanMode\x12\x1b\n\x17THERMOSTAT_FAN_MODE_OFF\x10\x00\x12 \n\x1cTHERMOSTAT_FAN_MODE_AUTO_LOW\x10\x01\x12\x1b\n\x17THERMOSTAT_FAN_MODE_LOW\x10\x02\x12!\n\x1dTHERMOSTAT_FAN_MODE_AUTO_HIGH\x10\x03\x12\x1c\n\x18THERMOSTAT_FAN_MODE_HIGH\x10\x04\x32\x86\x03\n\nThermostat\x12U\n\x11ThermostatModeSet\x12\".vemmiopb.ThermostatModeSetRequest\x1a\x1c.vemmiopb.ThermostatResponse\x12\x65\n\x14ThermostatModeSupGet\x12%.vemmiopb.ThermostatModeSupGetRequest\x1a&.vemmiopb.ThermostatModeSupGetResponse\x12]\n\x15ThermostatSetpointSet\x12&.vemmiopb.ThermostatSetpointSetRequest\x1a\x1c.vemmiopb.ThermostatResponse\x12[\n\x14ThermostatFanModeSet\x12%.vemmiopb.ThermostatFanModeSetRequest\x1a\x1c.vemmiopb.ThermostatResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.thermostat_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _THERMOSTATMODE._serialized_start=1140
  _THERMOSTATMODE._serialized_end=1259
  _THERMOSTATSETPOINTTYPE._serialized_start=1262
  _THERMOSTATSETPOINTTYPE._serialized_end=1391
  _THERMOSTATFANMODE._serialized_start=1394
  _THERMOSTATFANMODE._serialized_end=1570
  _THERMOSTATMODESETREQUEST._serialized_start=101
  _THERMOSTATMODESETREQUEST._serialized_end=211
  _THERMOSTATMODESUPGETREQUEST._serialized_start=213
  _THERMOSTATMODESUPGETREQUEST._serialized_end=286
  _THERMOSTATMODESUPGETRESPONSE._serialized_start=288
  _THERMOSTATMODESUPGETRESPONSE._serialized_end=359
  _THERMOSTATSETPOINTSETREQUEST._serialized_start=362
  _THERMOSTATSETPOINTSETREQUEST._serialized_end=532
  _THERMOSTATFANMODESETREQUEST._serialized_start=534
  _THERMOSTATFANMODESETREQUEST._serialized_end=654
  _THERMOSTATRESPONSE._serialized_start=656
  _THERMOSTATRESPONSE._serialized_end=676
  _THERMOSTATMODEREPORT._serialized_start=678
  _THERMOSTATMODEREPORT._serialized_end=740
  _THERMOSTATSETPOINTREPORT._serialized_start=742
  _THERMOSTATSETPOINTREPORT._serialized_end=816
  _THERMOSTATFANMODEREPORT._serialized_start=818
  _THERMOSTATFANMODEREPORT._serialized_end=890
  _THERMOSTATSETPOINTRANGE._serialized_start=893
  _THERMOSTATSETPOINTRANGE._serialized_end=1052
  _THERMOSTATSETPOINT._serialized_start=1054
  _THERMOSTATSETPOINT._serialized_end=1138
  _THERMOSTAT._serialized_start=1573
  _THERMOSTAT._serialized_end=1963
# @@protoc_insertion_point(module_scope)



from vemmio_client import metadata_pb2 as _metadata_pb2
from vemmio_client import units_pb2 as _units_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UltravioletGetRequest(_message.Message):
    __slots__ = ["metadata"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.DeviceMetadata
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ...) -> None: ...

class UltravioletGetResponse(_message.Message):
    __slots__ = ["unit", "value"]
    UNIT_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    unit: _units_pb2.Unit
    value: float
    def __init__(self, unit: _Optional[_Union[_units_pb2.Unit, str]] = ..., value: _Optional[float] = ...) -> None: ...

class UltravioletReport(_message.Message):
    __slots__ = ["unit", "value"]
    UNIT_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    unit: _units_pb2.Unit
    value: float
    def __init__(self, unit: _Optional[_Union[_units_pb2.Unit, str]] = ..., value: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/configuration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!vemmio_client/configuration.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\"F\n\x18\x43onfigurationListRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"K\n\x19\x43onfigurationListResponse\x12.\n\x07options\x18\x01 \x03(\x0b\x32\x1d.vemmiopb.ConfigurationOption\"T\n\x17\x43onfigurationGetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\r\n\x05index\x18\x02 \x01(\x05\"G\n\x18\x43onfigurationGetResponse\x12+\n\x05value\x18\x01 \x01(\x0b\x32\x1c.vemmiopb.ConfigurationValue\"\x81\x01\n\x17\x43onfigurationSetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\r\n\x05index\x18\x02 \x01(\x05\x12+\n\x05value\x18\x03 \x01(\x0b\x32\x1c.vemmiopb.ConfigurationValue\"\x1a\n\x18\x43onfigurationSetResponse\"q\n\x13\x43onfigurationOption\x12\r\n\x05index\x18\x01 \x01(\x05\x12\r\n\x05label\x18\x02 \x01(\t\x12\x0c\n\x04help\x18\x03 \x01(\t\x12.\n\x04type\x18\x04 \x01(\x0e\x32 .vemmiopb.ConfigurationValueType\"S\n\x12\x43onfigurationValue\x12\x34\n\x06scalar\x18\x01 \x01(\x0b\x32\".vemmiopb.ConfigurationValueScalarH\x00\x42\x07\n\x05value\"\xbd\x02\n\x18\x43onfigurationValueScalar\x12\x14\n\nbool_value\x18\x01 \x01(\x08H\x00\x12\x15\n\x0buint8_value\x18\x02 \x01(\rH\x00\x12\x16\n\x0cuint16_value\x18\x03 \x01(\rH\x00\x12\x16\n\x0cuint32_value\x18\x04 \x01(\rH\x00\x12\x16\n\x0cuint64_value\x18\x05 \x01(\x04H\x00\x12\x14\n\nint8_value\x18\x06 \x01(\x05H\x00\x12\x15\n\x0bint16_value\x18\x07 \x01(\x05H\x00\x12\x15\n\x0bint32_value\x18\x08 \x01(\x05H\x00\x12\x15\n\x0bint64_value\x18\t \x01(\x03H\x00\x12\x17\n\rfloat32_value\x18\n \x01(\x02H\x00\x12\x17\n\rfloat64_value\x18\x0b \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x0c \x01(\tH\x00\x42\x07\n\x05value*\xf6\x03\n\x16\x43onfigurationValueType\x12&\n\"CONFIGURATION_VALUE_TYPE_UNDEFINED\x10\x00\x12!\n\x1d\x43ONFIGURATION_VALUE_TYPE_BOOL\x10\x01\x12\"\n\x1e\x43ONFIGURATION_VALUE_TYPE_UINT8\x10\x02\x12#\n\x1f\x43ONFIGURATION_VALUE_TYPE_UINT16\x10\x03\x12#\n\x1f\x43ONFIGURATION_VALUE_TYPE_UINT32\x10\x04\x12#\n\x1f\x43ONFIGURATION_VALUE_TYPE_UINT64\x10\x05\x12!\n\x1d\x43ONFIGURATION_VALUE_TYPE_INT8\x10\x06\x12\"\n\x1e\x43ONFIGURATION_VALUE_TYPE_INT16\x10\x07\x12\"\n\x1e\x43ONFIGURATION_VALUE_TYPE_INT32\x10\x08\x12\"\n\x1e\x43ONFIGURATION_VALUE_TYPE_INT64\x10\t\x12$\n CONFIGURATION_VALUE_TYPE_FLOAT32\x10\n\x12$\n CONFIGURATION_VALUE_TYPE_FLOAT64\x10\x0b\x12#\n\x1f\x43ONFIGURATION_VALUE_TYPE_STRING\x10\x0c\x32\xa3\x02\n\rConfiguration\x12\\\n\x11\x43onfigurationList\x12\".vemmiopb.ConfigurationListRequest\x1a#.vemmiopb.ConfigurationListResponse\x12Y\n\x10\x43onfigurationGet\x12!.vemmiopb.ConfigurationGetRequest\x1a\".vemmiopb.ConfigurationGetResponse\x12Y\n\x10\x43onfigurationSet\x12!.vemmiopb.ConfigurationSetRequest\x1a\".vemmiopb.ConfigurationSetResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.configuration_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _CONFIGURATIONVALUETYPE._serialized_start=1066
  _CONFIGURATIONVALUETYPE._serialized_end=1568
  _CONFIGURATIONLISTREQUEST._serialized_start=77
  _CONFIGURATIONLISTREQUEST._serialized_end=147
  _CONFIGURATIONLISTRESPONSE._serialized_start=149
  _CONFIGURATIONLISTRESPONSE._serialized_end=224
  _CONFIGURATIONGETREQUEST._serialized_start=226
  _CONFIGURATIONGETREQUEST._serialized_end=310
  _CONFIGURATIONGETRESPONSE._serialized_start=312
  _CONFIGURATIONGETRESPONSE._serialized_end=383
  _CONFIGURATIONSETREQUEST._serialized_start=386
  _CONFIGURATIONSETREQUEST._serialized_end=515
  _CONFIGURATIONSETRESPONSE._serialized_start=517
  _CONFIGURATIONSETRESPONSE._serialized_end=543
  _CONFIGURATIONOPTION._serialized_start=545
  _CONFIGURATIONOPTION._serialized_end=658
  _CONFIGURATIONVALUE._serialized_start=660
  _CONFIGURATIONVALUE._serialized_end=743
  _CONFIGURATIONVALUESCALAR._serialized_start=746
  _CONFIGURATIONVALUESCALAR._serialized_end=1063
  _CONFIGURATION._serialized_start=1571
  _CONFIGURATION._serialized_end=1862
# @@protoc_insertion_point(module_scope)



from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from vemmio_client import accelerometer_pb2 as _accelerometer_pb2
from vemmio_client import battery_pb2 as _battery_pb2
from vemmio_client import bsensor_pb2 as _bsensor_pb2
from vemmio_client import carbon_dioxide_pb2 as _carbon_dioxide_pb2
from vemmio_client import carbon_monoxide_pb2 as _carbon_monoxide_pb2
from vemmio_client import color_pb2 as _color_pb2
from vemmio_client import door_pb2 as _door_pb2
from vemmio_client import doorbell_pb2 as _doorbell_pb2
from vemmio_client import emergency_pb2 as _emergency_pb2
from vemmio_client import firmware_pb2 as _firmware_pb2
from vemmio_client import flood_pb2 as _flood_pb2
from vemmio_client import gate_pb2 as _gate_pb2
from vemmio_client import level_pb2 as _level_pb2
from vemmio_client import lock_pb2 as _lock_pb2
from vemmio_client import metadata_pb2 as _metadata_pb2
from vemmio_client import meter_pb2 as _meter_pb2
from vemmio_client import power_source_pb2 as _power_source_pb2
from vemmio_client import remote_pb2 as _remote_pb2
from vemmio_client import roller_shutter_pb2 as _roller_shutter_pb2
from vemmio_client import seismic_pb2 as _seismic_pb2
from vemmio_client import sensor_pb2 as _sensor_pb2
from vemmio_client import siren_pb2 as _siren_pb2
from vemmio_client import smoke_pb2 as _smoke_pb2
from vemmio_client import status_pb2 as _status_pb2
from vemmio_client import structure_pb2 as _structure_pb2
from vemmio_client import switch_pb2 as _switch_pb2
from vemmio_client import tamper_pb2 as _tamper_pb2
from vemmio_client import taptap_pb2 as _taptap_pb2
from vemmio_client import temperature_pb2 as _temperature_pb2
from vemmio_client import thermostat_pb2 as _thermostat_pb2
from vemmio_client import ultraviolet_pb2 as _ultraviolet_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ConnectivityReport(_message.Message):
    __slots__ = ["state", "timestamp", "uptime"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    CONNECTED: ConnectivityReport.State
    DISCONNECTED: ConnectivityReport.State
    STATE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    UPTIME: ConnectivityReport.State
    UPTIME_FIELD_NUMBER: _ClassVar[int]
    state: ConnectivityReport.State
    timestamp: _timestamp_pb2.Timestamp
    uptime: _duration_pb2.Duration
    def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., state: _Optional[_Union[ConnectivityReport.State, str]] = ..., uptime: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class DeviceReport(_message.Message):
    __slots__ = ["accelerometer", "battery", "carbon_dioxide", "carbon_monoxide_state", "carbon_monoxide_value", "color", "direction", "door", "doorbell", "emergency", "flood", "gas_meter", "gate", "humidity", "illumination", "level", "lock", "metadata", "motion", "open_close", "power_meter", "power_source", "remote", "roller_shutter_level", "seismic_intensity", "seismic_magnitude", "siren", "smoke", "switch", "tamper", "tap_tap", "temperature", "thermostat_fan_mode", "thermostat_mode", "thermostat_setpoint", "timestamp", "tone", "ultraviolet", "volume", "water_meter"]
    ACCELEROMETER_FIELD_NUMBER: _ClassVar[int]
    BATTERY_FIELD_NUMBER: _ClassVar[int]
    CARBON_DIOXIDE_FIELD_NUMBER: _ClassVar[int]
    CARBON_MONOXIDE_STATE_FIELD_NUMBER: _ClassVar[int]
    CARBON_MONOXIDE_VALUE_FIELD_NUMBER: _ClassVar[int]
    COLOR_FIELD_NUMBER: _ClassVar[int]
    DIRECTION_FIELD_NUMBER: _ClassVar[int]
    DOORBELL_FIELD_NUMBER: _ClassVar[int]
    DOOR_FIELD_NUMBER: _ClassVar[int]
    EMERGENCY_FIELD_NUMBER: _ClassVar[int]
    FLOOD_FIELD_NUMBER: _ClassVar[int]
    GAS_METER_FIELD_NUMBER: _ClassVar[int]
    GATE_FIELD_NUMBER: _ClassVar[int]
    HUMIDITY_FIELD_NUMBER: _ClassVar[int]
    ILLUMINATION_FIELD_NUMBER: _ClassVar[int]
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    LOCK_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    MOTION_FIELD_NUMBER: _ClassVar[int]
    OPEN_CLOSE_FIELD_NUMBER: _ClassVar[int]
    POWER_METER_FIELD_NUMBER: _ClassVar[int]
    POWER_SOURCE_FIELD_NUMBER: _ClassVar[int]
    REMOTE_FIELD_NUMBER: _ClassVar[int]
    ROLLER_SHUTTER_LEVEL_FIELD_NUMBER: _ClassVar[int]
    SEISMIC_INTENSITY_FIELD_NUMBER: _ClassVar[int]
    SEISMIC_MAGNITUDE_FIELD_NUMBER: _ClassVar[int]
    SIREN_FIELD_NUMBER: _ClassVar[int]
    SMOKE_FIELD_NUMBER: _ClassVar[int]
    SWITCH_FIELD_NUMBER: _ClassVar[int]
    TAMPER_FIELD_NUMBER: _ClassVar[int]
    TAP_TAP_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    THERMOSTAT_FAN_MODE_FIELD_NUMBER: _ClassVar[int]
    THERMOSTAT_MODE_FIELD_NUMBER: _ClassVar[int]
    THERMOSTAT_SETPOINT_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TONE_FIELD_NUMBER: _ClassVar[int]
    ULTRAVIOLET_FIELD_NUMBER: _ClassVar[int]
    VOLUME_FIELD_NUMBER: _ClassVar[int]
    WATER_METER_FIELD_NUMBER: _ClassVar[int]
    accelerometer: _accelerometer_pb2.AccelerometerReport
    battery: _battery_pb2.BatteryReport
    carbon_dioxide: _carbon_dioxide_pb2.CarbonDioxideReport
    carbon_monoxide_state: _carbon_monoxide_pb2.CarbonMonoxideStateReport
    carbon_monoxide_value: _carbon_monoxide_pb2.CarbonMonoxideValueReport
    color: _color_pb2.ColorReport
    direction: _sensor_pb2.DirectionReport
    door: _door_pb2.DoorReport
    doorbell: _doorbell_pb2.DoorbellReport
    emergency: _emergency_pb2.EmergencyReport
    flood: _flood_pb2.FloodReport
    gas_meter: _meter_pb2.MeterReport
    gate: _gate_pb2.GateReport
    humidity: _sensor_pb2.HumidityReport
    illumination: _sensor_pb2.IlluminationReport
    level: _level_pb2.LevelReport
    lock: _lock_pb2.LockReport
    metadata: _metadata_pb2.DeviceMetadata
    motion: _bsensor_pb2.MotionReport
    open_close: _bsensor_pb2.OpenCloseReport
    power_meter: _meter_pb2.MeterReport
    power_source: _power_source_pb2.PowerSourceReport
    remote: _remote_pb2.RemoteReport
    roller_shutter_level: _roller_shutter_pb2.RollerShutterLevelReport
    seismic_intensity: _seismic_pb2.SeismicIntensityReport
    seismic_magnitude: _seismic_pb2.SeismicMagnitudeReport
    siren: _siren_pb2.SirenReport
    smoke: _smoke_pb2.SmokeReport
    switch: _switch_pb2.SwitchReport
    tamper: _tamper_pb2.TamperReport
    tap_tap: _taptap_pb2.TapTapReport
    temperature: _temperature_pb2.TemperatureReport
    thermostat_fan_mode: _thermostat_pb2.ThermostatFanModeReport
    thermostat_mode: _thermostat_pb2.ThermostatModeReport
    thermostat_setpoint: _thermostat_pb2.ThermostatSetpointReport
    timestamp: _timestamp_pb2.Timestamp
    tone: _siren_pb2.ToneReport
    ultraviolet: _ultraviolet_pb2.UltravioletReport
    volume: _siren_pb2.VolumeReport
    water_meter: _meter_pb2.MeterReport
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., switch: _Optional[_Union[_switch_pb2.SwitchReport, _Mapping]] = ..., power_meter: _Optional[_Union[_meter_pb2.MeterReport, _Mapping]] = ..., gas_meter: _Optional[_Union[_meter_pb2.MeterReport, _Mapping]] = ..., water_meter: _Optional[_Union[_meter_pb2.MeterReport, _Mapping]] = ..., open_close: _Optional[_Union[_bsensor_pb2.OpenCloseReport, _Mapping]] = ..., smoke: _Optional[_Union[_smoke_pb2.SmokeReport, _Mapping]] = ..., motion: _Optional[_Union[_bsensor_pb2.MotionReport, _Mapping]] = ..., flood: _Optional[_Union[_flood_pb2.FloodReport, _Mapping]] = ..., carbon_monoxide_state: _Optional[_Union[_carbon_monoxide_pb2.CarbonMonoxideStateReport, _Mapping]] = ..., temperature: _Optional[_Union[_temperature_pb2.TemperatureReport, _Mapping]] = ..., humidity: _Optional[_Union[_sensor_pb2.HumidityReport, _Mapping]] = ..., illumination: _Optional[_Union[_sensor_pb2.IlluminationReport, _Mapping]] = ..., direction: _Optional[_Union[_sensor_pb2.DirectionReport, _Mapping]] = ..., thermostat_mode: _Optional[_Union[_thermostat_pb2.ThermostatModeReport, _Mapping]] = ..., thermostat_setpoint: _Optional[_Union[_thermostat_pb2.ThermostatSetpointReport, _Mapping]] = ..., thermostat_fan_mode: _Optional[_Union[_thermostat_pb2.ThermostatFanModeReport, _Mapping]] = ..., tamper: _Optional[_Union[_tamper_pb2.TamperReport, _Mapping]] = ..., emergency: _Optional[_Union[_emergency_pb2.EmergencyReport, _Mapping]] = ..., door: _Optional[_Union[_door_pb2.DoorReport, _Mapping]] = ..., tap_tap: _Optional[_Union[_taptap_pb2.TapTapReport, _Mapping]] = ..., color: _Optional[_Union[_color_pb2.ColorReport, _Mapping]] = ..., level: _Optional[_Union[_level_pb2.LevelReport, _Mapping]] = ..., battery: _Optional[_Union[_battery_pb2.BatteryReport, _Mapping]] = ..., remote: _Optional[_Union[_remote_pb2.RemoteReport, _Mapping]] = ..., lock: _Optional[_Union[_lock_pb2.LockReport, _Mapping]] = ..., doorbell: _Optional[_Union[_doorbell_pb2.DoorbellReport, _Mapping]] = ..., power_source: _Optional[_Union[_power_source_pb2.PowerSourceReport, _Mapping]] = ..., siren: _Optional[_Union[_siren_pb2.SirenReport, _Mapping]] = ..., tone: _Optional[_Union[_siren_pb2.ToneReport, _Mapping]] = ..., volume: _Optional[_Union[_siren_pb2.VolumeReport, _Mapping]] = ..., accelerometer: _Optional[_Union[_accelerometer_pb2.AccelerometerReport, _Mapping]] = ..., seismic_intensity: _Optional[_Union[_seismic_pb2.SeismicIntensityReport, _Mapping]] = ..., seismic_magnitude: _Optional[_Union[_seismic_pb2.SeismicMagnitudeReport, _Mapping]] = ..., roller_shutter_level: _Optional[_Union[_roller_shutter_pb2.RollerShutterLevelReport, _Mapping]] = ..., carbon_dioxide: _Optional[_Union[_carbon_dioxide_pb2.CarbonDioxideReport, _Mapping]] = ..., carbon_monoxide_value: _Optional[_Union[_carbon_monoxide_pb2.CarbonMonoxideValueReport, _Mapping]] = ..., ultraviolet: _Optional[_Union[_ultraviolet_pb2.UltravioletReport, _Mapping]] = ..., gate: _Optional[_Union[_gate_pb2.GateReport, _Mapping]] = ...) -> None: ...

class GatewayReport(_message.Message):
    __slots__ = ["connectivity", "device", "firmware_update_status", "mac", "status_check", "structure"]
    CONNECTIVITY_FIELD_NUMBER: _ClassVar[int]
    DEVICE_FIELD_NUMBER: _ClassVar[int]
    FIRMWARE_UPDATE_STATUS_FIELD_NUMBER: _ClassVar[int]
    MAC_FIELD_NUMBER: _ClassVar[int]
    STATUS_CHECK_FIELD_NUMBER: _ClassVar[int]
    STRUCTURE_FIELD_NUMBER: _ClassVar[int]
    connectivity: ConnectivityReport
    device: DeviceReport
    firmware_update_status: _firmware_pb2.FirmwareUpdateStatusReport
    mac: str
    status_check: _status_pb2.StatusCheckReport
    structure: _structure_pb2.StructureReport
    def __init__(self, mac: _Optional[str] = ..., connectivity: _Optional[_Union[ConnectivityReport, _Mapping]] = ..., device: _Optional[_Union[DeviceReport, _Mapping]] = ..., status_check: _Optional[_Union[_status_pb2.StatusCheckReport, _Mapping]] = ..., firmware_update_status: _Optional[_Union[_firmware_pb2.FirmwareUpdateStatusReport, _Mapping]] = ..., structure: _Optional[_Union[_structure_pb2.StructureReport, _Mapping]] = ...) -> None: ...

class ReportRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/meter.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2
from vemmio_client import units_pb2 as vemmio__client_dot_units__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vemmio_client/meter.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\x1a\x19vemmio_client/units.proto\"[\n\x0fMeterGetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\x1c\n\x04unit\x18\x02 \x01(\x0e\x32\x0e.vemmiopb.Unit\"?\n\x10MeterGetResponse\x12\x1c\n\x04unit\x18\x01 \x01(\x0e\x32\x0e.vemmiopb.Unit\x12\r\n\x05value\x18\x02 \x01(\x01\"?\n\x11MeterResetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"\x14\n\x12MeterResetResponse\":\n\x0bMeterReport\x12\x1c\n\x04unit\x18\x01 \x01(\x0e\x32\x0e.vemmiopb.Unit\x12\r\n\x05value\x18\x02 \x01(\x01\x32\x93\x01\n\x05Meter\x12\x41\n\x08MeterGet\x12\x19.vemmiopb.MeterGetRequest\x1a\x1a.vemmiopb.MeterGetResponse\x12G\n\nMeterReset\x12\x1b.vemmiopb.MeterResetRequest\x1a\x1c.vemmiopb.MeterResetResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.meter_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _METERGETREQUEST._serialized_start=96
  _METERGETREQUEST._serialized_end=187
  _METERGETRESPONSE._serialized_start=189
  _METERGETRESPONSE._serialized_end=252
  _METERRESETREQUEST._serialized_start=254
  _METERRESETREQUEST._serialized_end=317
  _METERRESETRESPONSE._serialized_start=319
  _METERRESETRESPONSE._serialized_end=339
  _METERREPORT._serialized_start=341
  _METERREPORT._serialized_end=399
  _METER._serialized_start=402
  _METER._serialized_end=549
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18vemmio_client/info.proto\x12\x08vemmiopb\"\r\n\x0bInfoRequest\"v\n\x0cInfoResponse\x12\x13\n\x0b\x63ommon_name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x12\n\ngit_commit\x18\x03 \x01(\t\x12\x12\n\nbuild_time\x18\x04 \x01(\t\x12\x18\n\x10\x66irmware_version\x18\x05 \x01(\t2=\n\x04Info\x12\x35\n\x04Info\x12\x15.vemmiopb.InfoRequest\x1a\x16.vemmiopb.InfoResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.info_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _INFOREQUEST._serialized_start=38
  _INFOREQUEST._serialized_end=51
  _INFORESPONSE._serialized_start=53
  _INFORESPONSE._serialized_end=171
  _INFO._serialized_start=173
  _INFO._serialized_end=234
# @@protoc_insertion_point(module_scope)



from vemmio_client import metadata_pb2 as _metadata_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RollerShutterLevelReport(_message.Message):
    __slots__ = ["value"]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: int
    def __init__(self, value: _Optional[int] = ...) -> None: ...

class RollerShutterRequest(_message.Message):
    __slots__ = ["metadata"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.DeviceMetadata
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ...) -> None: ...

class RollerShutterResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class RollerShutterSetRequest(_message.Message):
    __slots__ = ["level", "metadata"]
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    level: int
    metadata: _metadata_pb2.DeviceMetadata
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ..., level: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/roller_shutter.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"vemmio_client/roller_shutter.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\"B\n\x14RollerShutterRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"T\n\x17RollerShutterSetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\r\n\x05level\x18\x02 \x01(\x05\"\x17\n\x15RollerShutterResponse\")\n\x18RollerShutterLevelReport\x12\r\n\x05value\x18\x01 \x01(\x05\x32\x94\x02\n\rRollerShutter\x12T\n\x11RollerShutterOpen\x12\x1e.vemmiopb.RollerShutterRequest\x1a\x1f.vemmiopb.RollerShutterResponse\x12U\n\x12RollerShutterClose\x12\x1e.vemmiopb.RollerShutterRequest\x1a\x1f.vemmiopb.RollerShutterResponse\x12V\n\x10RollerShutterSet\x12!.vemmiopb.RollerShutterSetRequest\x1a\x1f.vemmiopb.RollerShutterResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.roller_shutter_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _ROLLERSHUTTERREQUEST._serialized_start=78
  _ROLLERSHUTTERREQUEST._serialized_end=144
  _ROLLERSHUTTERSETREQUEST._serialized_start=146
  _ROLLERSHUTTERSETREQUEST._serialized_end=230
  _ROLLERSHUTTERRESPONSE._serialized_start=232
  _ROLLERSHUTTERRESPONSE._serialized_end=255
  _ROLLERSHUTTERLEVELREPORT._serialized_start=257
  _ROLLERSHUTTERLEVELREPORT._serialized_end=298
  _ROLLERSHUTTER._serialized_start=301
  _ROLLERSHUTTER._serialized_end=577
# @@protoc_insertion_point(module_scope)
